Model definitions for Nomy wallet analysis data processing.
This file is generated automatically from the Python models. Do not edit this file manually.
Model definitions for Nomy wallet analysis data processing.
This file is generated automatically from the Python models. Do not edit this file manually.