EnrichedTrade model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.
Structs
- Enriched
Trade - Model for storing enriched trade data with PnL calculations.
EnrichedTrade model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.