PositionTrade model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.
Structs
- Position
Trade - Model linking a trade event to a position’s lifecycle.
PositionTrade model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.