ServiceState model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.
Structs
- Service
State - Model for tracking service processing states.
ServiceState model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.