Module wallet_state

Module wallet_state 

WalletState model definition.

This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.

Structs

WalletState
Model for tracking wallet data quality and completeness state.