WalletState model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.
Structs
- Wallet
State - Model for tracking wallet data quality and completeness state.
WalletState model definition.
This file is generated automatically from the Python SQLAlchemy model. Do not edit this file manually.